@@ -1,8 +1,10 @@
 qvcalc <- function(object, factorname=NULL, dispersion=NULL,
                    estimates=NULL, modelcall=NULL)
 {
-  require(MASS, quietly = TRUE)  
+  if (version$major == 1 && version$minor < 6.0) {
+      require(MASS, quietly = TRUE)  
       ## for generic function vcov() and related methods
+  }
   if (!is.matrix(object)) {  ## i.e., object is a model
       if (is.null(factorname)) stop("argument \"factorname\" missing")
       model <- object
@@ -11,11 +13,12 @@ qvcalc <- function(object, factorname=NULL, dispersion=NULL,
       modelmat <- if (is.matrix(model$x)) model$x
                   else model.matrix(terms(model), data=model$model)
       coef.indices <- which(attr(modelmat,"assign") == term.index)
-      contmat <- eval(call(model$contrasts[[factorname]],
-                           model$xlevels[[factorname]]))
-#      rownames(contmat) <- paste(factorname,
-#                                 model$xlevels[[factorname]],
-#                                 sep="")
+      if (length(model$xlevels[[factorname]])==length(coef.indices)){
+      ## factor has no constraint applied, eg if no intercept in model
+          contmat <- diag(length(coef.indices))}
+      else {
+          contmat <- eval(call(model$contrasts[[factorname]],
+                           model$xlevels[[factorname]]))}
       rownames(contmat) <- model$xlevels[[factorname]]
       if (is.null(estimates))
           estimates <- contmat %*% coef(model)[coef.indices]
@@ -168,7 +171,7 @@ summary.qv <- function(object, ...)
 }
 
 plot.qv <- function(x, width=2, ylab = "estimate",
-                    main = "Quasi-independent interval estimates",
+                    main = "Intervals based on quasi standard errors",
                     ...) {
     frame <- x$qvframe
     if (is.na(frame$estimate[1]))
